@@ -1,7 +1,6 @@
 import logging
 
-_log_format = "%(asctime)s [%(levelname)s]: [%(app)s, %(name)s] - " \
-              "(%(filename)s).%(funcName)s(%(lineno)d) - %(message)s"
+_log_format = "%(asctime)s [%(levelname)s]: [%(app)s, %(name)s] - %(message)s"
 
 def info(msg, *args):
     if logger:
@@ -69,4 +68,5 @@ def create_logger(logger_name='default', app_name='app', level="INFO",
     logger.setLevel('INFO')
     return logger
 
-logger = create_logger()
\ No newline at end of file
+logger = create_logger()
+#logger = None
\ No newline at end of file
